@@ -519,7 +519,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         else:
             raise Exception('Please give either a dataset id or a dataset slug')
 
-    def create_datacard(self, channel_name: str, title: str, search: str = "", slug: str = None, skin_code:str = None, replace: bool = False):
+    def create_datacard(self, channel_slug: str, title: str, search: str = "", slug: str = None, skin_code:str = None, replace: bool = False):
 
         if (replace == True and slug != None):
             try:
@@ -531,11 +531,11 @@ class Agent(Insight, Channel, Catalog, Dataset):
             print("Please specify a datacard slug to replace!")
             return
 
-        channel = self.get_channel(channel_name)
+        channel = self.get_channel(channel_slug)
         if channel is not None:
             channel_id = channel["id"]
         else:
-            channel_id = self.create_channel(channel_name)
+            channel_id = self.create_channel(channel_slug)
 
         body = {
             "agentId": self._agentId,
@@ -725,14 +725,14 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r.raise_for_status()
 
 
-    def get_channel(self, channel_code):
+    def get_channel(self, channel_slug):
 
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        url = self._base_url_ch + '/channels?agentId=' + self._agentId + '&slug=' + channel_code
+        url = self._base_url_ch + '/channels?agentId=' + self._agentId + '&slug=' + channel_slug
         r = s.get(url=url, headers=self._headers)
         r.raise_for_status()
         if (r != None and r.json() != []):
