@@ -211,12 +211,12 @@ def read_google_ads(n_range = 7,
 
 def read_aircall_calls(token, api_key, #mandatory
                       
-                      start = 7, end = 0 #optional
+                      start_date = '2022-01-01', end_date = '2022-01-07' #optional
                      ):
     
     from askdata.integrations import aircall_api
     
-    aircall_calls = aircall_api.get_aircall_calls(token, api_key, start, end)
+    aircall_calls = aircall_api.get_aircall_calls(token, api_key, start_date, end_date)
     
     return aircall_calls
     
