@@ -20,11 +20,11 @@ MANDATORY INPUT: token, api_key
 
 OPTIONAL INPUT:
 
-- start: n days ago for starting the date range.
-        Default start = 7 days ago.
+- start_date: start date range.
+        Default start_date = '2022-01-01'
         
-- end: n days ago for ending the date range.
-        Default end = 0 days ago.
+- end_date: end date range.
+        Default end_date = '2022-01-07'
 
 
 """
@@ -34,16 +34,16 @@ OPTIONAL INPUT:
 
 def get_aircall_calls(token, api_key, #mandatory
                       
-                      start = 7, end = 0 #optional
+                      start_date = '2022-01-01', end_date = '2022-01-07' #optional
                      ):
 
     
     
-    start_date = (dt.today()-td(days = start)).isoformat()
+    #start_date = (dt.today()-td(days = start)).isoformat()
     # converted to UNIX timefromat 
     start_date = math.trunc(time.mktime(datetime.datetime.strptime(start_date, "%Y-%m-%d").timetuple()))
 
-    end_date = (dt.today()-td(days = end)).isoformat()
+    #end_date = (dt.today()-td(days = end)).isoformat()
     # converted to UNIX timefromat 
     end_date = math.trunc(time.mktime(datetime.datetime.strptime(end_date, "%Y-%m-%d").timetuple()))
     
